<?php
require_once 'config.php';
j2_leagues_matches_past();

function j2_leagues_matches_past(){
    global $wpdb;
    global $conn;
    
    // Call APi Parameter [Lang - League ID - Season ID]
    $lang = isset($_GET['lang']) && strlen($_GET['lang']) === 2 ? $_GET['lang'] : '';
    $league_id = isset($_GET['league_id']) && (int)$_GET['league_id'] ? $_GET['league_id'] : null;
    $season_id = isset($_GET['season_id']) ? $_GET['season_id'] : null;

    // SQL To Get App Order From Dashboard
    $sql = "SELECT * FROM wp_options WHERE option_name='app_order'";
    $Table_Order = query($sql)[0];
    $Table_Order = ($Table_Order['option_value'] == 'goal_difference') ? 'GD' : 'H2H';

    // SQL To Get App Season From Dashboard
    $sql = "SELECT * FROM `wp_options` WHERE `option_name` ='app_season'";
    $app_season = query($sql);
    $season_id = (int) $app_season[0]['option_value'];
    $order_by = $Table_Order; // H2H (direct match) or GD (goal difference)

    // Error Message If API Not Has League Id Or Season ID
    if (!$league_id || !$season_id) {
        $json_pretty = json_encode(['status' => 'false', 'message' => 'Missing League ID'], JSON_UNESCAPED_UNICODE);
        header('Content-Type: application/json');
        echo $json_pretty;
        exit;
    }

    // SQL To Get Data Fr League By ID
    $sql = "SELECT * FROM sp_leagues WHERE term_id={$league_id}";
    $league = query($sql)[0];
    $lang = $league['lang'];
    

   // Check If League Has 3_round Enabled
if (isset($league['3_round']) && $league['3_round'] == 'enabled') {
    // If 3_round is enabled, fetch points from match meta directly

    // Get Matches in This League and Season including 'future' status
    $sql = "SELECT * FROM sp_events 
            WHERE (post_status = 'publish' OR post_status = 'future') 
            AND league_id='{$league_id}' 
            AND season_id='{$season_id}' 
            AND trash_status IS NULL";
    $matches = query($sql);

    // Error Message If Count Matches Equal 0
    if (count($matches) == 0) {
        $json_pretty = json_encode(['status' => 'false', 'message' => 'No Matches Exist'], JSON_UNESCAPED_UNICODE);
        header('Content-Type: application/json');
        echo $json_pretty;
        exit;
    }

    // Get Teams IDs From All Matches
    $teams_string = '';
    foreach ($matches as $match) {
        if (!isset($match['teams']))
            continue;
        $teams_string .= trim($match['teams']) . ',';
        $teams_string = str_replace(' ', '', $teams_string);
    }
    $teams_ids = explode(',', $teams_string);
    $teams_ids = array_unique($teams_ids);
    $teams_ids = array_filter($teams_ids);
    $teams_string = rtrim(implode(',', $teams_ids), ', ');

    // Get Site URL To Get Right Path For Images
    $siteURLQuery = query("SELECT option_value FROM wp_options WHERE option_name = 'siteurl'");
    $siteURL = $siteURLQuery[0]['option_value'];
    $uploadsPath = $siteURL . '/wp-content/uploads/';

    // Get Data For Teams
    $sql = "SELECT sp_teams.ID as id, sp_teams.post_title title, CONCAT('{$uploadsPath}', sp_teams.img) as image FROM sp_teams WHERE ID IN ({$teams_string}) AND lang='{$lang}'";
    $teams = query($sql, true);

    // Query wp_standings_update for additional data To Update Standings Data By Results
    $sql = "SELECT * FROM wp_standings_update WHERE league_id='{$league_id}' AND season_id='{$season_id}'";
    $standings = query($sql);

    // Prepare standings data with existing results
    $standings_data = [];
    foreach ($standings as $standing) {
        $team_id = (int)$standing['team_id'];
        if (!isset($standings_data[$team_id])) {
            $standings_data[$team_id] = [
                "games" => 0,
                "win" => 0,
                "draw" => 0,
                "lose" => 0,
                "has_goals" => 0,
                "Goals_on_him" => 0,
                "Goal_difference" => 0,
                "points" => 0,
                "position" => 0,
            ];
        }
        $standings_data[$team_id]['games'] += (int)$standing['played'];
        $standings_data[$team_id]['win'] += (int)$standing['win'];
        $standings_data[$team_id]['draw'] += (int)$standing['draw'];
        $standings_data[$team_id]['lose'] += (int)$standing['lose'];
        $standings_data[$team_id]['has_goals'] += (int)$standing['goals_for'];
        $standings_data[$team_id]['Goals_on_him'] += (int)$standing['goals_against'];
        $standings_data[$team_id]['Goal_difference'] += (int)$standing['goals_diff'];
        $standings_data[$team_id]['points'] += (int)$standing['points'];
        $standings_data[$team_id]['position'] = (int)$standing['position'];  // Assuming position is already set
    }

    // Prepare standings for teams
    $standings_teams = [];
    foreach ($teams as $team) {
        $team_id = $team['id'];
        if (isset($standings_data[$team_id])) {
            $standings_teams[$team_id] = $standings_data[$team_id]; // Pre-load existing data
        } else {
            $standings_teams[$team_id] = [
                "games" => 0,
                "points" => 0,
                "win" => 0,
                "draw" => 0,
                "lose" => 0,
                "has_goals" => 0,
                "Goals_on_him" => 0,
                "Goal_difference" => 0
            ];
        }
    }

    // Loop through matches and add points and stats conditionally
    $today = date('Y-m-d'); // Current date in 'YYYY-MM-DD' format

    foreach ($matches as $match) {
        $post_date = isset($match['post_date']) ? date('Y-m-d', strtotime($match['post_date'])) : '';
        $match_status = $match['match_status'] ?? '';
        
        // If match is in the future or not ended today, skip calculations
        if ($post_date > $today || ($post_date == $today && $match_status != 'Ended')) {
            continue;
        }

        $team_ids = explode(',', str_replace(' ', '', $match['teams'] ?? '') ?? '');
        if (count($team_ids) < 2) continue;

        $team_1_id = $team_ids[0];
        $team_2_id = $team_ids[1];

        // Access points directly from the match data
        $team_1_points = $match['match_team_1_3d_point'] ?? 0;
        $team_2_points = $match['match_team_2_3d_point'] ?? 0;

        // Add points to the standings data
        $standings_teams[$team_1_id]['points'] += (int)$team_1_points;
        $standings_teams[$team_1_id]['games'] += 1;

        $standings_teams[$team_2_id]['points'] += (int)$team_2_points;
        $standings_teams[$team_2_id]['games'] += 1;

        // Calculate wins, draws, losses, and goal stats
        $result = $match['match_result'] ?? '';
        if ($result) {
            $results = unserialize($result);
            if ($results && count($results) > 0) {
                if (in_array($team_1_id, $team_ids) && in_array($team_2_id, $team_ids)) {
                    $team_1_goals = $results[$team_1_id]['goals'] ?? 0;
                    $team_2_goals = $results[$team_2_id]['goals'] ?? 0;

                    if ($team_1_points > $team_2_points) {
                        $standings_teams[$team_1_id]['win'] += 1;
                        $standings_teams[$team_2_id]['lose'] += 1;
                    } elseif ($team_1_points < $team_2_points) {
                        $standings_teams[$team_1_id]['lose'] += 1;
                        $standings_teams[$team_2_id]['win'] += 1;
                    }
                    // else {
                    //     $standings_teams[$team_1_id]['draw'] += 1;
                    //     $standings_teams[$team_2_id]['draw'] += 1;
                    // }

                    $standings_teams[$team_1_id]['has_goals'] += $team_1_goals;
                    $standings_teams[$team_1_id]['Goals_on_him'] += $team_2_goals;
                    $standings_teams[$team_1_id]['Goal_difference'] += ($team_1_goals - $team_2_goals);

                    $standings_teams[$team_2_id]['has_goals'] += $team_2_goals;
                    $standings_teams[$team_2_id]['Goals_on_him'] += $team_1_goals;
                    $standings_teams[$team_2_id]['Goal_difference'] += ($team_2_goals - $team_1_goals);
                }
            }
        }
    }

    // Final standings array (sort and assign positions)
    usort($teams, function($a, $b) use ($standings_teams) {
        return $standings_teams[$b['id']]['points'] <=> $standings_teams[$a['id']]['points']
            ?: $standings_teams[$b['id']]['Goal_difference'] <=> $standings_teams[$a['id']]['Goal_difference'];
    });

    foreach ($teams as $position => $team) {
        $team_id = $team['id'];
        $standings_teams[$team_id]['position'] = $position + 1;
        $teams[$position]['table_stats'] = $standings_teams[$team_id];
    }

    // JSON response
    $response = [
        'table' => [
            [
                'league_id' => $league_id,
                'season_id' => $season_id,
                'lang' => $lang,
                'title' => 'Order',
                'table_order' => ['DESC'],
                'table_sp_orderby' => ['points'],
                'teams' => $teams
            ]
        ]
    ];

    $json_pretty = json_encode($response, JSON_UNESCAPED_UNICODE | JSON_PRETTY_PRINT);
    header('Content-Type: application/json');
    echo $json_pretty;
    exit;
}
else {

        // Check If League Prevent To Showing In App Or Prevent Showing Standings In App
        if (isset($league['hide_standings_in_app']) && $league['hide_standings_in_app'] == 'true') {
            $json_pretty = json_encode(['status' => 'false', 'message' => 'this is cup not standings is required'], JSON_UNESCAPED_UNICODE);
            header('Content-Type: application/json');
            echo $json_pretty;
            exit;
        }

        // Get Today Date
        $today = date('Y-m-d');
        
        // Get All Matched In This League, Season, Played Today Or In Past And Match Status Is Ended
        $sql = "SELECT * FROM sp_events 
                WHERE post_status = 'publish' 
                AND league_id='{$league_id}' 
                AND season_id='{$season_id}' 
                AND trash_status IS NULL 
                AND (DATE(post_date) < '{$today}' 
                    OR (DATE(post_date) = '{$today}' AND match_status = 'Ended'))";
        $matches = query($sql);

        // Error Message IF Count Matches Equal 0
        if (count($matches) == 0) {
            $json_pretty = json_encode(['status' => 'false', 'message' => 'No Matches Exist'], JSON_UNESCAPED_UNICODE);
            header('Content-Type: application/json');
            echo $json_pretty;
            exit;
        }

        // Get Teams IDS From All Matches
        $teams_string = '';
        foreach ($matches as $match) {
            if (!isset($match['teams']))
                continue;
            $teams_string .= trim($match['teams']) . ',';
            $teams_string = str_replace(' ', '', $teams_string);
        }
        $teams_ids = explode(',', $teams_string);
        $teams_ids = array_unique($teams_ids);
        $teams_ids = array_filter($teams_ids);
        $teams_string = rtrim(implode(',', $teams_ids), ', ');

        // Get Site URL To Get Right Path For Iamges
        $siteURLQuery = query("SELECT option_value FROM wp_options WHERE option_name = 'siteurl'");
        $siteURL = $siteURLQuery[0]['option_value'];
        $uploadsPath = $siteURL . '/wp-content/uploads/';

        // Get Data For Tean
        $sql = "SELECT sp_teams.ID as id, sp_teams.post_title title, CONCAT('{$uploadsPath}', sp_teams.img) as image FROM sp_teams WHERE ID IN ({$teams_string}) AND lang='{$lang}'";
        $teams = query($sql, true);

        // Query wp_standings_update for additional data To Update Standings Data By Results
        $sql = "SELECT * FROM wp_standings_update WHERE league_id='{$league_id}' AND season_id='{$season_id}'";
        $standings = query($sql);

        $standings_data = [];
        foreach ($standings as $standing) {
            $team_id = (int)$standing['team_id'];
            if (!isset($standings_data[$team_id])) {
                $standings_data[$team_id] = [
                    "games" => 0,
                    "win" => 0,
                    "draw" => 0,
                    "lose" => 0,
                    "has_goals" => 0,
                    "Goals_on_him" => 0,
                    "Goal_difference" => 0,
                    "points" => 0,
                    "position" => 0,
                ];
            }
            $standings_data[$team_id]['games'] += (int)$standing['played'];
            $standings_data[$team_id]['win'] += (int)$standing['win'];
            $standings_data[$team_id]['draw'] += (int)$standing['draw'];
            $standings_data[$team_id]['lose'] += (int)$standing['lose'];
            $standings_data[$team_id]['has_goals'] += (int)$standing['goals_for'];
            $standings_data[$team_id]['Goals_on_him'] += (int)$standing['goals_against'];
            $standings_data[$team_id]['Goal_difference'] += (int)$standing['goals_diff'];
            $standings_data[$team_id]['points'] += (int)$standing['points'];
            $standings_data[$team_id]['position'] += (int)$standing['position'];
        }
        
        // Loop teams to get results
        foreach ($teams as $k => $team) {
            $team_id = (int)$team['id'];

            $table_stats = [
                "games" => 0,
                "win" => 0,
                "draw" => 0,
                "lose" => 0,
                "has_goals" => 0,
                "Goals_on_him" => 0,
                "Goal_difference" => 0,
                "points" => 0
            ];
            $direct_match = [];

            if (isset($standings_data[$team_id])) {
                foreach ($standings_data[$team_id] as $key => $value) {
                    $table_stats[$key] += $value;
                }
            }

            foreach ($matches as $match) {
                if (substr($match['post_date'], 0, 10) > $today)
                    continue;

                $result = $match['match_result'] ?? '';
                if (!isset($result))
                    continue;

                $results = unserialize($result);
                $team_ids = explode(',', str_replace(' ', '', $match['teams'] ?? '') ?? '');

                if (!$results || count($results) == 0)
                    continue;

                if (!in_array($team_id, $team_ids))
                    continue;

                // [games]
                $table_stats['games'] += 1;

                $resultMatch1 = !empty($results[trim($team_ids[0])]) ? $results[trim($team_ids[0])] : null;
                $resultMatch2 = !empty($results[trim($team_ids[1])]) ? $results[trim($team_ids[1])] : null;
                if ($team_id == $team_ids[0]) {
                    $other_id = $team_ids[1];
                } elseif ($team_id == $team_ids[1]) {
                    $other_id = $team_ids[0];
                }
                $my_result = $results[$team_id];
                $other_result = !empty($results[trim($other_id)]) ? $results[trim($other_id)] : null;
                $g = intval($my_result['goals']);
                $g_other = intval($other_result['goals']);

                $outcome = $my_result['outcome'];
                if (is_array($outcome))
                    $outcome = $outcome[0];

                $g1 = isset($resultMatch1['goals']) ? intval($resultMatch1['goals']) : '';
                $g2 = isset($resultMatch2['goals']) ? intval($resultMatch2['goals']) : '';
                if ($g1 == '' && $g2 == '')
                    continue;

                if ($outcome == 'win') {
                    $direct_match[] = [$other_id => $g];
                }

                if (is_array($outcome) && count($outcome) == 0) {
                    $table_stats['draw'] += 1;
                } else {
                    $table_stats['win'] += ($outcome == 'win') ? 1 : 0;
                    $table_stats['draw'] += ($outcome == 'draw') ? 1 : 0;
                    $table_stats['lose'] += ($outcome == 'lose') ? 1 : 0;
                }

                $table_stats['has_goals'] += $g;
                $table_stats['points'] += $outcome == 'win' ? Win_Points : (($outcome == 'draw') ? 1 : 0);
                $table_stats['Goal_difference'] += ($g - $g_other);
                $table_stats['Goals_on_him'] += $g_other;
            }

            $teams[$k]['id'] = (int)$team['id'];
            $teams[$k]['table_stats'] = $table_stats;
            $teams[$k]['image'] = $team['image'];
            $teams[$k]['title'] = $team['title'];
        }

        usort($teams, function ($a, $b) {
            if ($b['table_stats']['points'] == $a['table_stats']['points']) {
                return $b['table_stats']['Goal_difference'] <=> $a['table_stats']['Goal_difference'];
            }
            return $b['table_stats']['points'] <=> $a['table_stats']['points'];
        });

        foreach ($teams as $k => $team) {
            $team_id = (int)$team['id'];
            $final_position1 = $k + 1;
            
            // Update positions in wp_standings_update table
            $update_sql = "UPDATE wp_standings_update SET position_org={$final_position1} WHERE league_id={$league_id} AND season_id={$season_id} AND team_id={$team_id}";
            $update_result = $conn->query($update_sql);
            
            // Update positions in $teams array
            $final_position = $final_position1 + ($standings_data[$team_id]['position'] ?? 0);
            $teams[$k]['table_stats']['position'] = $final_position;
        }


        // Order the teams by final position
        usort($teams, function ($a, $b) {
            return $a['table_stats']['position'] <=> $b['table_stats']['position'];
        });
        
        $response = [
            "table" => [
                [
                    "league_id" => (int)$league_id,
                    "season_id" => $season_id,
                    "lang" => $lang,
                    "title" => "Order",
                    "table_order" => ["DESC"],
                    "table_sp_orderby" => ["points"],
                    "teams" => $teams
                ]
            ]
        ];

        $json_pretty = json_encode($response, JSON_UNESCAPED_UNICODE | JSON_PRETTY_PRINT);
        header('Content-Type: application/json');
        echo $json_pretty;
    }
}
?>
