<?php
require_once 'config.php';
j2_leagues_matches_past();

function j2_leagues_matches_past(){
    global $wpdb;
    global $conn;
    $lang = isset($_GET['lang']) && strlen($_GET['lang']) === 2 ? $_GET['lang'] : 'ar';
    $id = isset($_GET['id']) && (int)$_GET['id'] ? $_GET['id'] : null;

    // Get app season
    $sql = "SELECT * FROM `wp_options` WHERE `option_name` ='app_season'";
    $app_season = query($sql);
    $season_id = (int)$app_season[0]['option_value'];
    $siteURLQuery = query("SELECT option_value FROM wp_options WHERE option_name = 'siteurl'");
    $siteURL = $siteURLQuery[0]['option_value'];

    // Get leagues
    $leagues_array = array();
    $sql = "SELECT * FROM sp_leagues WHERE lang='{$lang}'";
    if ($id) {
        $sql .= " AND term_id={$id}";
    }
    $leagues = query($sql);

    // Get teams
    $sql = "SELECT * FROM sp_teams WHERE lang='{$lang}'";
    $teams = query($sql);

    // Get matches for the next 60 days
    $sql = "SELECT * FROM sp_events WHERE trash_status IS NULL AND season_id='{$season_id}' AND league_id IS NOT NULL AND lang='{$lang}' AND DATE(post_date) >= DATE(NOW()) AND DATE(post_date) < DATE_ADD(CURDATE(), INTERVAL 60 DAY) ORDER BY post_date DESC";
    $matches = query($sql);

    $today = date('Y-m-d');
    $day7 = date('Y-m-d', strtotime("+7 days"));
    $day60 = date('Y-m-d', strtotime("+60 days")); // Extend search to 60 days
    $period = 'no_have_matches';

    if (isset($matches) && count($matches) > 0) {
        foreach (array_reverse($matches) as $match) {
            if (substr($match['post_date'], 0, 10) == $today) {
                $period = 'one_day';
                break;
            }
            if (substr($match['post_date'], 0, 10) > $today && substr($match['post_date'], 0, 10) <= $day7) {
                $period = 'one_week';
                break;
            }
            if (substr($match['post_date'], 0, 10) > $day7 && substr($match['post_date'], 0, 10) <= $day60) {
                $period = 'up_to_two_months'; // New period for up to 60 days
                break;
            }
        }
    } else {
        $period = 'no_have_matches';
    }

    foreach ($leagues as $league) {
        $matches_array = [];
        $match_count = 0; // Counter to limit matches to 4 if period exceeds 14 days

        foreach ($matches as $match) {
            if ($period == 'one_day' && substr($match['post_date'], 0, 10) !== $today) {
                continue;
            }
            if ($period == 'one_week' && substr($match['post_date'], 0, 10) > $day7) {
                continue;
            }
            if ($period == 'up_to_two_months' && substr($match['post_date'], 0, 10) > $day60) {
                continue;
            }

            if ($match['league_id'] != $league['term_id']) {
                continue;
            }

            // Apply limit of 4 matches if period is greater than today (one_week or up_to_two_months)
            if (($period == 'one_week' || $period == 'up_to_two_months') && $match_count >= 4) {
                break; // Stop adding more matches if limit is reached
            }

            // Get Result
            $result = $match['match_result'] ?? '';
            $results = unserialize($result);
            $team_ids = explode(',', $match['teams'] ?? '');

            if (!is_array($team_ids) || !isset($team_ids[1])) {
                continue;
            }

            $key_id = array_search($team_ids[0], array_column($teams, 'ID'));
            $team = $teams[$key_id];
            $resultMatch1 = !empty($results[trim($team_ids[0])]) ? $results[trim($team_ids[0])] : null;
            $resultMatch2 = !empty($results[trim($team_ids[1])]) ? $results[trim($team_ids[1])] : null;

            $g1 = isset($resultMatch1['goals']) ? intval($resultMatch1['goals']) : '';
            $g2 = isset($resultMatch2['goals']) ? intval($resultMatch2['goals']) : '';

            if ($g1 == $g2) {
                $outcome1 = 'draw';
                $outcome2 = 'draw';
            } elseif ($g1 > $g2) {
                $outcome1 = 'win';
                $outcome2 = 'lose';
            } elseif ($g1 < $g2) {
                $outcome1 = 'lose';
                $outcome2 = 'win';
            } else {
                $outcome1 = '';
                $outcome2 = '';
            }

            $first_team = [
                'id' => (int)$team_ids[0],
                'title' => $team['post_title'],
                'image' => $siteURL . '/wp-content/uploads/' . $team['img'],
                'results' => [
                    'firsthalf' => isset($resultMatch1['firsthalf']) ? intval($resultMatch1['firsthalf']) : '',
                    'secondhalf' => isset($resultMatch1['secondhalf']) ? intval($resultMatch1['secondhalf']) : '',
                    'goals' => $g1,
                    'outcome' => $outcome1,
                ],
            ];

            $key_id = array_search($team_ids[1], array_column($teams, 'ID'));
            $team = $teams[$key_id];

            $second_team = [
                'id' => (int)$team_ids[1],
                'title' => $team['post_title'],
                'image' => $siteURL . '/wp-content/uploads/' . $team['img'],
                'results' => [
                    'firsthalf' => isset($resultMatch2['firsthalf']) ? intval($resultMatch2['firsthalf']) : '',
                    'secondhalf' => isset($resultMatch2['secondhalf']) ? intval($resultMatch2['secondhalf']) : '',
                    'goals' => $g2,
                    'outcome' => $outcome2,
                ],
            ];

            $matches_array[] = [
                "id" => (int)$match['ID'],
                "title" => $match['post_title'],
                "date" => substr($match['post_date'], 0, 10),
                "time" => substr($match['post_date'], 11, 8),
                "status" => $match['match_status'],
                "week" => $match['sp_day'],
                "venue" => [$match['venue']],
                "teams" => [
                    'first_team' => $first_team,
                    'second_team' => $second_team
                ]
            ];

            // Increment match counter if the period is greater than today
            if ($period == 'one_week' || $period == 'up_to_two_months') {
                $match_count++;
            }
        }

        if (count($matches_array) < 1) {
            continue;
        }

        $leagues_array[] = array(
            'id' => (int)$league['term_id'],
            'name' => $league['name'],
            'order' => (int)$league['lorder'],
            'matches' => $matches_array,
        );
    }

    // Prepare JSON response
    $leagues_array = [
        'data' => $period,
        'matches' => [
            'leagues' => $leagues_array
        ]
    ];
    $json_pretty = json_encode($leagues_array, JSON_UNESCAPED_UNICODE);

    // Output JSON response
    header('Content-Type: application/json');
    echo $json_pretty;
    exit;
}
